@@ -40,8 +40,7 @@ def _log(msg, application, level,execution_time, user_id, extra_data):
         formatter = logging.Formatter('%(message)s')
         handler.setFormatter(formatter)
         logger.addHandler(handler) 
-
-        logger.warning(json.dumps(data))
+        logger.warning(json.dumps(data)+"\n")
         logger.removeHandler(handler)
 
         return data
@@ -51,16 +50,16 @@ def _notify(msg):
         requests.post(url, data = {"message": json.dumps(msg), "channel": msg['application']})    
 
 
-def warning(msg, application,  execution_time=None, user_id=None, extra_data=None):
+def warning(msg, application=None,  execution_time=None, user_id=None, extra_data=None):
         _log(msg, application,config('WARNING') ,execution_time, user_id, extra_data)
         
-def info(msg, application,  execution_time=None, user_id=None, extra_data=None):
+def info(msg, application=None,  execution_time=None, user_id=None, extra_data=None):
         _log(msg, application,config('INFO') ,execution_time, user_id, extra_data) 
 
-def error(msg, application,  execution_time=None, user_id=None, extra_data=None):
+def error(msg, application=None,  execution_time=None, user_id=None, extra_data=None):
         _log(msg, application,config('ERROR') ,execution_time, user_id, extra_data)      
 
-def critical(msg, application,  execution_time=None, user_id=None, extra_data=None):
+def critical(msg, application=None,  execution_time=None, user_id=None, extra_data=None):
         _notify(_log(msg, application,config('CRITICAL') ,execution_time, user_id, extra_data))
 
 
